@@ -349,7 +349,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
 
     def set_code_cookie(self, code):
         self.set_secure_cookie(
-            CODE_COOKIE_NAME, code, expires_days=config.oauth_expiry, httponly=True
+            CODE_COOKIE_NAME, code, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path
         )
 
     async def get(self):
@@ -423,7 +423,7 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
                           type(handler).__name__, user_key)
                 raise HTTPError(401, "OAuth token payload missing user information")
             handler.clear_cookie('is_guest')
-            handler.set_secure_cookie('user', user, expires_days=config.oauth_expiry, httponly=True)
+            handler.set_secure_cookie('user', user, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         else:
             user = None
 
@@ -433,14 +433,14 @@ class OAuthLoginHandler(tornado.web.RequestHandler, OAuth2Mixin):
                 id_token = state.encryption.encrypt(id_token.encode('utf-8'))
             if refresh_token:
                 refresh_token = state.encryption.encrypt(refresh_token.encode('utf-8'))
-        handler.set_secure_cookie('access_token', access_token, expires_days=config.oauth_expiry, httponly=True)
+        handler.set_secure_cookie('access_token', access_token, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         if id_token:
-            handler.set_secure_cookie('id_token', id_token, expires_days=config.oauth_expiry, httponly=True)
+            handler.set_secure_cookie('id_token', id_token, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         if expires_in:
             now_ts = dt.datetime.now(dt.timezone.utc).timestamp()
-            handler.set_secure_cookie('oauth_expiry', str(int(now_ts + expires_in)), expires_days=config.oauth_expiry, httponly=True)
+            handler.set_secure_cookie('oauth_expiry', str(int(now_ts + expires_in)), expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         if refresh_token:
-            handler.set_secure_cookie('refresh_token', refresh_token, expires_days=config.oauth_expiry, httponly=True)
+            handler.set_secure_cookie('refresh_token', refresh_token, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         if user and user in state._oauth_user_overrides:
             state._oauth_user_overrides.pop(user, None)
         return user
@@ -862,11 +862,11 @@ class BasicLoginHandler(RequestHandler):
             self.clear_cookie("user")
             return
         self.clear_cookie("is_guest")
-        self.set_secure_cookie("user", user, expires_days=config.oauth_expiry, httponly=True)
+        self.set_secure_cookie("user", user, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
         id_token = base64url_encode(json.dumps({'user': user}))
         if state.encryption:
             id_token = state.encryption.encrypt(id_token.encode('utf-8'))
-        self.set_secure_cookie('id_token', id_token, expires_days=config.oauth_expiry, httponly=True)
+        self.set_secure_cookie('id_token', id_token, expires_days=config.oauth_expiry, httponly=True, path=config.cookie_path)
 
 
 class LogoutHandler(tornado.web.RequestHandler):
@@ -955,7 +955,7 @@ class BasicAuthProvider(AuthProvider):
                 user = "guest"
                 request_handler.request.cookies["is_guest"] = "1"
                 if not isinstance(request_handler, WebSocketHandler):
-                    request_handler.set_cookie("is_guest", "1", expires_days=config.oauth_expiry)
+                    request_handler.set_cookie("is_guest", "1", expires_days=config.oauth_expiry, path=config.cookie_path)
 
             if user and isinstance(request_handler, WebSocketHandler):
                 state._active_users[user] += 1
