@@ -52,7 +52,7 @@ class _SliderBase(Widget):
         Whether the slider should go from left-to-right ('ltr') or
         right-to-left ('rtl').""")
 
-    name = param.String(default=None, doc="""
+    name = param.String(default=None, constant=False, doc="""
         The name of the widget. Also used as the label of the widget. If not set,
         the widget has no label.""")
 
@@ -379,7 +379,6 @@ class DiscreteSlider(CompositeWidget, _SliderBase):
         A custom format string. Separate from format parameter since
         formatting is applied in Python, not via the bokeh TickFormatter.""")
 
-
     _rename: ClassVar[Mapping[str, str | None]] = {'formatter': None}
 
     _source_transforms: ClassVar[Mapping[str, str | None]] = {
@@ -564,7 +563,6 @@ class DiscreteSlider(CompositeWidget, _SliderBase):
         return list(self.options.values()) if isinstance(self.options, dict) else self.options
 
 
-
 class _RangeSliderBase(_SliderBase):
 
     value = param.Tuple(default=(None, None), length=2, allow_None=False, nested_refs=True, doc="""
